"""
Init for file for teams package.
"""
# flake8: noqa

from .teams import Teams
